@@ -1,7 +1,7 @@
 print.RV.multcomp <- function (x,digits=4,...) {
   cat(paste("\n        Pairwise comparisons using ",x$method,"\n\n",sep=""))
   if (exists("model",where=x)) {
-    cat(paste("model:  ",x$model,"\n\n",sep=""))
+    cat(paste("model:  ",paste(x$model,collapse="\n\t"),"\n\n",sep=""))
   }
   if (exists("data.name",where=x)) {
     cat(paste("data:  ",x$data.name,"\n\n",sep=""))
